==> haskell-hls-module-name-plugin-2.0.0.0-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-module-name-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-module-name-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-module-name-plugin-2.0.0.0-9JVdl8ERpsz4qnsN39uSd1
key:                  hls-module-name-plugin-2.0.0.0-9JVdl8ERpsz4qnsN39uSd1
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Module name plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  76bd9518cc3e960e30904923f4442fec
exposed:              True
exposed-modules:      Ide.Plugin.ModuleName
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-module-name-plugin-2.0.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-module-name-plugin-2.0.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-module-name-plugin-2.0.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-module-name-plugin
hs-libraries:         HShls-module-name-plugin-2.0.0.0-9JVdl8ERpsz4qnsN39uSd1
depends:
    aeson-2.1.2.1-Kzzie09M6AYFH8VDx0mx86 base-4.17.2.1
    directory-1.3.7.1 filepath-1.4.2.2
    ghcide-2.0.0.0-HhfN95i5olV1pc7AjSOGut
    hls-plugin-api-2.0.0.0-FAIeqCBT2eqIcXKHXT4ELC
    lsp-1.6.0.0-ILXvXfUSiTJ29uGakQXc7N text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-6lPJVAOvNaZ2RxvZwsH66g

haddock-interfaces:
    /usr/share/doc/haskell-hls-module-name-plugin/html/hls-module-name-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-module-name-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-module-name-plugin-2.0.0.0-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-module-name-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-module-name-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-module-name-plugin-2.0.0.0-7uyTO1yHNNqLT7CmUgqooM
key:                  hls-module-name-plugin-2.0.0.0-7uyTO1yHNNqLT7CmUgqooM
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Module name plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  4325fd04df89e2abcaa05a4bd964f311
exposed:              True
exposed-modules:      Ide.Plugin.ModuleName
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-module-name-plugin-2.0.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-module-name-plugin-2.0.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-module-name-plugin-2.0.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-module-name-plugin
hs-libraries:         HShls-module-name-plugin-2.0.0.0-7uyTO1yHNNqLT7CmUgqooM
depends:
    aeson-2.1.2.1-Kzzie09M6AYFH8VDx0mx86 base-4.17.2.1
    directory-1.3.7.1 filepath-1.4.2.2
    ghcide-2.0.0.0-9oH2zLPxq7bG9eucRDJgzk
    hls-plugin-api-2.0.0.0-4lOfG8sQIby38NRZazCSl6
    lsp-1.6.0.0-ILXvXfUSiTJ29uGakQXc7N text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-6lPJVAOvNaZ2RxvZwsH66g

haddock-interfaces:
    /usr/share/doc/haskell-hls-module-name-plugin/html/hls-module-name-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-module-name-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
